@@ -28,20 +28,21 @@ import (
 	"github.com/prometheus/client_golang/prometheus"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
 	"golang.org/x/sync/errgroup"
+	"k8s.io/client-go/tools/clientcmd"
 
 	cmo "github.com/openshift/cluster-monitoring-operator/pkg/operator"
 )
 
-type tags map[string]string
+type images map[string]string
 
-func (t *tags) String() string {
-	m := *t
+func (i *images) String() string {
+	m := *i
 	slice := m.asSlice()
 	return strings.Join(slice, ",")
 }
 
-func (t *tags) Set(value string) error {
-	m := *t
+func (i *images) Set(value string) error {
+	m := *i
 	pairs := strings.Split(value, ",")
 	for _, pair := range pairs {
 		splitPair := strings.Split(pair, "=")
@@ -55,49 +56,73 @@ func (t *tags) Set(value string) error {
 	return nil
 }
 
-func (t tags) asSlice() []string {
+func (i images) asSlice() []string {
 	pairs := []string{}
-	for name, tag := range t {
+	for name, tag := range i {
 		pairs = append(pairs, name+"="+tag)
 	}
 	return pairs
 }
 
-func (t tags) asMap() map[string]string {
-	res := make(map[string]string, len(t))
-	for k, v := range t {
+func (i images) asMap() map[string]string {
+	res := make(map[string]string, len(i))
+	for k, v := range i {
 		res[k] = v
 	}
 	return res
 }
 
-func (t *tags) Type() string {
+func (i *images) Type() string {
 	return "map[string]string"
 }
 
 func Main() int {
 	flagset := flag.CommandLine
 	namespace := flagset.String("namespace", "openshift-monitoring", "Namespace to deploy and manage cluster monitoring stack in.")
+	namespaceSelector := flagset.String("namespace-selector", "openshift.io/cluster-monitoring=true", "Selector for namespaces to monitor.")
 	configMapName := flagset.String("configmap", "cluster-monitoring-config", "ConfigMap name to configure the cluster monitoring stack.")
-	tags := tags{}
-	flag.Var(&tags, "tags", "Tags to use for images.")
+	kubeconfigPath := flagset.String("kubeconfig", "", "The path to the kubeconfig to connect to the apiserver with.")
+	apiserver := flagset.String("apiserver", "", "The address of the apiserver to talk to.")
+	releaseVersion := flagset.String("release-version", "", "Currently targeted release version to be reconciled against.")
+	images := images{}
+	flag.Var(&images, "images", "Images to use for containers managed by the cluster-monitoring-operator.")
 	flag.Parse()
 
+	ok := true
 	if *namespace == "" {
+		ok = false
 		fmt.Fprint(os.Stderr, "`--namespace` flag is required, but not specified.")
 	}
 
 	if *configMapName == "" {
+		ok = false
 		fmt.Fprint(os.Stderr, "`--configmap` flag is required, but not specified.")
 	}
 
+	if releaseVersion == nil || *releaseVersion == "" {
+		fmt.Fprint(os.Stderr, "`--release-version` flag is not set.")
+	}
+	if releaseVersion != nil {
+		glog.V(4).Infof("Release version set to %v", *releaseVersion)
+	}
+
+	if !ok {
+		return 1
+	}
+
 	r := prometheus.NewRegistry()
 	r.MustRegister(
 		prometheus.NewGoCollector(),
-		prometheus.NewProcessCollector(os.Getpid(), ""),
+		prometheus.NewProcessCollector(prometheus.ProcessCollectorOpts{}),
 	)
 
-	o, err := cmo.New(*namespace, *configMapName, tags.asMap())
+	config, err := clientcmd.BuildConfigFromFlags(*apiserver, *kubeconfigPath)
+	if err != nil {
+		fmt.Fprint(os.Stderr, err)
+		return 1
+	}
+
+	o, err := cmo.New(config, *releaseVersion, *namespace, *namespaceSelector, *configMapName, images.asMap())
 	if err != nil {
 		fmt.Fprint(os.Stderr, err)
 		return 1
@@ -124,7 +149,7 @@ func Main() int {
 
 	cancel()
 	if err := wg.Wait(); err != nil {
-		glog.V(4).Infof("Unhandled error received. Exiting...err: %v", err)
+		glog.V(4).Infof("Unhandled error received. Exiting...err: %s", err)
 		return 1
 	}
 
